********
Citation
********

If you would like to cite Nengo in your research, please cite `this
paper <http://compneuro.uwaterloo.ca/files/publications/bekolay.2014.pdf>`_:

   Bekolay, Bergstra, Hunsberger, DeWolf, Stewart, Rasmussen, Choo,
   Voelker & Eliasmith. (2014) Nengo: a Python tool for building large-scale
   functional brain models. Frontiers in Neuroinformatics 7.

A BibTeX entry for LaTeX users is:

.. code-block:: tex

   @article{
     Bekolay2014,
     title = {Nengo: a {Python} tool for building large-scale functional brain models},
     author = {Bekolay, Trevor and Bergstra, James and Hunsberger, Eric
               and DeWolf, Travis and Stewart, Terrence and Rasmussen, Daniel
               and Choo, Xuan and Voelker, Aaron and Eliasmith, Chris},
     journal = {Frontiers in Neuroinformatics},
     pages = {1--13},
     volume = {7},
     number = {48},
     year = {2014},
     issn = {1662-5196},
     doi = {10.3389/fninf.2013.00048}
   }
